==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/user/messages/sq/account.php <==
<?php
return array (
  '<strong>Account</strong> Settings' => '',
  '<strong>Confirm</strong></strong> your new email address' => '',
  '<strong>Permissions</strong>' => '',
  '<strong>User</strong> Account' => '',
  '<strong>Your</strong> profile' => '',
  'Account Settings' => '',
  'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
  'All your personal data will be irrevocably deleted.' => '',
  'Are you sure that you want to delete your account?' => '',
  'Blocked users' => '',
  'Changing the username can make some links unusable, for example old links to the profile.' => '',
  'Confirm' => '',
  'Current password' => '',
  'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
  'Delete account' => '',
  'Do you really want to delete your icon image?' => '',
  'Do you really want to delete your logo image?' => '',
  'E-Mail' => '',
  'E-Mail change' => '',
  'Enter your password to continue' => '',
  'Hello' => '',
  'Here you can edit your general profile data, which is visible in the about page of your profile.' => '',
  'Hide introduction tour panel on dashboard' => '',
  'Invalid link! Please make sure that you entered the entire url.' => '',
  'Language' => 'Gjuhe',
  'Modules' => 'Modulet',
  'New E-Mail address' => '',
  'New User name' => '',
  'Not registered users' => '',
  'Notifications' => 'Njoftimet',
  'Other users' => '',
  'Password Recovery' => '',
  'Permissions' => 'Lejet',
  'Profile' => '',
  'Profile Tags' => '',
  'Profile visibility' => '',
  'Registered users only' => '',
  'Save' => '',
  'Save profile' => '',
  'The entered e-mail address is already in use by another user.' => '',
  'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
  'TimeZone' => '',
  'Username has been changed' => '',
  'Users' => 'Përdoruesit',
  'Visible for all (also unregistered users)' => '',
  'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => '',
  'You are currently the owner of following spaces:' => '',
  'You cannot use this username.' => '',
  'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => '',
  'You have successfully changed your username.<br>Your new username is {newUsername}.' => '',
  'You must transfer ownership or delete these spaces before you can delete your account.' => '',
  'Your account cannot be deleted!' => '',
  'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => '',
  'Your current password can be changed here.' => '',
  'Your current username is <b>{username}</b>. You can change your current username here.' => '',
  'Your e-mail address has been successfully changed to {email}.' => '',
  'Your friends' => '',
  'Your password has been successfully changed!' => '',
  'Your username has been changed' => '',
  'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => '',
  '{attribute} "{value}" was not found!' => '',
);

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/user/messages/sq/account.php <==
<?php
return array (
  '<strong>Account</strong> Settings' => '',
  '<strong>Confirm</strong></strong> your new email address' => '',
  '<strong>Permissions</strong>' => '',
  '<strong>Your</strong> Account' => '',
  '<strong>Your</strong> profile' => '',
  'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
  'All your personal data will be irrevocably deleted.' => '',
  'Are you sure that you want to delete your account?' => '',
  'Blocked users' => '',
  'Changing the username can make some links unusable, for example old links to the profile.' => '',
  'Confirm' => '',
  'Current password' => '',
  'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
  'Delete account' => '',
  'Do you really want to delete your icon image?' => '',
  'Do you really want to delete your logo image?' => '',
  'E-Mail' => '',
  'E-Mail change' => '',
  'Enter your password to continue' => '',
  'General' => 'Gjeneral',
  'Hello' => '',
  'Here you can edit your general profile data, which is visible in the about page of your profile.' => '',
  'Hide introduction tour panel on dashboard' => '',
  'Hide my online status' => '',
  'Invalid link! Please make sure that you entered the entire url.' => '',
  'Language' => 'Gjuhe',
  'Markdown Editor Mode' => '',
  'Modules' => 'Modulet',
  'New E-Mail address' => '',
  'New User name' => '',
  'Not registered users' => '',
  'Notifications' => 'Njoftimet',
  'Other users' => '',
  'Password Recovery' => '',
  'Permissions' => 'Lejet',
  'Plain' => '',
  'Profile' => '',
  'Profile Tags' => '',
  'Profile visibility' => '',
  'Registered users only' => '',
  'Rich Text' => '',
  'Save' => '',
  'Save profile' => '',
  'The entered e-mail address is already in use by another user.' => '',
  'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
  'TimeZone' => '',
  'Username has been changed' => '',
  'Users' => 'Përdoruesit',
  'Visible for all (also unregistered users)' => '',
  'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => '',
  'You are currently the owner of following spaces:' => '',
  'You cannot use this username.' => '',
  'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => '',
  'You have successfully changed your username.<br>Your new username is {newUsername}.' => '',
  'You must transfer ownership or delete these spaces before you can delete your account.' => '',
  'Your account cannot be deleted!' => '',
  'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => '',
  'Your current password can be changed here.' => '',
  'Your current username is <b>{username}</b>. You can change your current username here.' => '',
  'Your e-mail address has been successfully changed to {email}.' => '',
  'Your friends' => '',
  'Your password has been successfully changed!' => '',
  'Your username has been changed' => '',
  'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => '',
);
